import { _ParameterConstraints } from "./_ParameterConstraints";
import { NodeHttpOptions as __HttpOptions__ } from "@aws-sdk/types";
import * as __aws_sdk_types from "@aws-sdk/types";
/**
 * CreateRouteInput shape
 */
export interface CreateRouteInput {
    /**
     * <p>The API identifier.</p>
     */
    ApiId: string;
    /**
     * <p>Specifies whether an API key is required for the route.</p>
     */
    ApiKeyRequired?: boolean;
    /**
     * <p>The authorization scopes supported by this
     *  route.</p>
     */
    AuthorizationScopes?: Array<string> | Iterable<string>;
    /**
     * <p>The authorization type for the route. Valid values are NONE for open
     *  access, AWS_IAM for using AWS IAM permissions, and CUSTOM
     *  for using a Lambda
     *  authorizer.</p>
     */
    AuthorizationType?: "NONE" | "AWS_IAM" | "CUSTOM" | string;
    /**
     * <p>The identifier of the Authorizer resource to be associated with this
     *  route, if the authorizationType is CUSTOM
     *  . The authorizer identifier is generated by API Gateway
     *  when you created the authorizer.</p>
     */
    AuthorizerId?: string;
    /**
     * <p>The model selection expression for the route.</p>
     */
    ModelSelectionExpression?: string;
    /**
     * <p>The operation name for the route.</p>
     */
    OperationName?: string;
    /**
     * <p>The request models for the route.</p>
     */
    RequestModels?: {
        [key: string]: string;
    } | Iterable<[string, string]>;
    /**
     * <p>The request parameters for the route.</p>
     */
    RequestParameters?: {
        [key: string]: _ParameterConstraints;
    } | Iterable<[string, _ParameterConstraints]>;
    /**
     * <p>The route key for the route.</p>
     */
    RouteKey: string;
    /**
     * <p>The route response selection expression for the route.</p>
     */
    RouteResponseSelectionExpression?: string;
    /**
     * <p>The target for the route.</p>
     */
    Target?: string;
    /**
     * The maximum number of times this operation should be retried. If set, this value will override the `maxRetries` configuration set on the client for this command.
     */
    $maxRetries?: number;
    /**
     * An object that may be queried to determine if the underlying operation has been aborted.
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/API/AbortSignal
     */
    $abortSignal?: __aws_sdk_types.AbortSignal;
    /**
     * Per-request HTTP configuration options. If set, any options specified will override the corresponding HTTP option set on the client for this command.
     */
    $httpOptions?: __HttpOptions__;
}
